get_behaviour_memdump: Get Behaviour Memory Dump

View source: R/get_behaviour_memdump.R

get_behaviour_memdumpR Documentation

Get Behaviour Memory Dump

Description

Retrieves the memory dump file from a sandbox analysis.

Usage

get_behaviour_memdump(sandbox_id = NULL, output_path = NULL, ...)

Arguments

sandbox_id

Sandbox report ID (character string). Required.

output_path

Local path to save the memory dump file. Optional.

...

Ignored. Configure requests with the package options instead (see virustotal).

Value

Raw memory dump content or saves to file if output_path specified

References

https://docs.virustotal.com/reference

See Also

set_key for setting the API key, get_behaviour_report for JSON report

Examples

## Not run: 

# Before calling the function, set the API key using set_key('api_key_here')

memdump <- get_behaviour_memdump(sandbox_id = 'hash_sandboxname')
get_behaviour_memdump(
  sandbox_id = 'hash_sandboxname',
  output_path = '/tmp/memory.dmp'
)

## End(Not run)

virustotal documentation built on Aug. 20, 2026, 5:07 p.m.