get_domain_comments: Retrieve comments for an Internet domain

View source: R/get_domain_comments.R

get_domain_commentsR Documentation

Retrieve comments for an Internet domain

Description

Retrieve comments for an Internet domain

Usage

get_domain_comments(domain = NULL, limit = NULL, cursor = NULL, ...)

Arguments

domain

domain name. String. Required.

limit

Number of entries. Integer. Optional. Default is 10.

cursor

String. Optional.

...

Additional arguments passed to virustotal_GET.

Value

list containing domain comment data including comment text, authors, dates, and any associated metadata from the VirusTotal v3.0 API

References

https://docs.virustotal.com/reference

See Also

set_key for setting the API key

Examples

## Not run: 

# Before calling the function, set the API key using set_key('api_key_here')

get_domain_comments("http://www.google.com")
get_domain_comments("http://www.goodsfwrfw.com") # Domain not found

## End(Not run)

virustotal documentation built on April 13, 2026, 9:07 a.m.