Verifies that the API key is set and appears to be valid format.
See also
Other security:
sanitize_domain(),
sanitize_file_path(),
sanitize_hash(),
sanitize_ip(),
sanitize_url(),
security-utilities
Verifies that the API key is set and appears to be valid format.
Other security:
sanitize_domain(),
sanitize_file_path(),
sanitize_hash(),
sanitize_ip(),
sanitize_url(),
security-utilities