| security-utilities | R Documentation |
Security functions for input sanitization and validation to prevent common security issues when working with potentially malicious inputs.
Other security:
is_api_key_configured(),
sanitize_domain(),
sanitize_file_path(),
sanitize_hash(),
sanitize_ip(),
sanitize_url()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.