Custom error classes for structured error handling in the virustotal package.
See also
Other error handling:
virustotal_auth_error(),
virustotal_check(),
virustotal_error(),
virustotal_rate_limit_error(),
virustotal_validation_error()
Custom error classes for structured error handling in the virustotal package.
Other error handling:
virustotal_auth_error(),
virustotal_check(),
virustotal_error(),
virustotal_rate_limit_error(),
virustotal_validation_error()