The canonical environment variable is VIRUSTOTAL_API_KEY;
VirustotalToken is the historical name and is still honored.
set_key() sets both.
See also
Other authentication:
has_vt_key(),
set_key()
The canonical environment variable is VIRUSTOTAL_API_KEY;
VirustotalToken is the historical name and is still honored.
set_key() sets both.
Other authentication:
has_vt_key(),
set_key()