| file_report | R Documentation |
Retrieves detailed analysis results for a file from VirusTotal using the v3 API.
file_report(hash, ...)
hash |
File hash (MD5, SHA1, or SHA256) or analysis ID |
... |
Additional arguments passed to |
A virustotal_file_report object containing file analysis results
including antivirus scans, file metadata, and threat detection information
https://docs.virustotal.com/reference/files
set_key for setting the API key, scan_file for submitting files
## Not run:
# Set API key first
set_key('your_api_key_here')
# Get file report using hash
report <- file_report(hash = '99017f6eebbac24f351415dd410d522d')
print(report)
summary(report)
# Work with the rich nested structure returned by v3 API
print(report$data$attributes$last_analysis_stats)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.